summaryrefslogtreecommitdiffstats
path: root/src/gui/studio/MidiProgramsEditor.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2013-02-01 23:16:04 -0600
committerTimothy Pearson <[email protected]>2013-02-01 23:16:04 -0600
commit990bf92fa5cefbe5ebb34a172d18bb3df745bd7a (patch)
treea458e45739951ac897cb2ca9cd172a30bdcc6e2f /src/gui/studio/MidiProgramsEditor.h
parentfb3718a55f355cd22f9eb9fa4e89cd3b84b8c9ca (diff)
downloadrosegarden-990bf92fa5cefbe5ebb34a172d18bb3df745bd7a.tar.gz
rosegarden-990bf92fa5cefbe5ebb34a172d18bb3df745bd7a.zip
Rename many classes and header files to avoid conflicts with KDE4
Diffstat (limited to 'src/gui/studio/MidiProgramsEditor.h')
-rw-r--r--src/gui/studio/MidiProgramsEditor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/gui/studio/MidiProgramsEditor.h b/src/gui/studio/MidiProgramsEditor.h
index 7d40e8e..f583ec3 100644
--- a/src/gui/studio/MidiProgramsEditor.h
+++ b/src/gui/studio/MidiProgramsEditor.h
@@ -78,9 +78,9 @@ protected:
int ensureUniqueMSB(int msb, bool ascending);
int ensureUniqueLSB(int lsb, bool ascending);
// Does the banklist contain this combination already?
//
- bool banklistContains(const MidiBank &);
+ bool bantdelistContains(const MidiBank &);
ProgramList getBankSubset(const MidiBank &);
@@ -78,9 +78,9 @@ protected:
int ensureUniqueMSB(int msb, bool ascending);
int ensureUniqueLSB(int lsb, bool ascending);
- // Does the banklist contain this combination already?
+ // Does the bantdelist contain this combination already?
//